Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(103)

Unified Diff: components/autofill/content/renderer/autofill_agent.h

Issue 2775963002: s/same_page/same_document for DidCommitProvisionalLoad method. (Closed)
Patch Set: Addressed review comment Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/autofill/content/renderer/autofill_agent.h
diff --git a/components/autofill/content/renderer/autofill_agent.h b/components/autofill/content/renderer/autofill_agent.h
index 698e5c9fc7095503c76b086d4e83ee42a96b3ffd..c6a275dd995eb8d466fabb8508e6df99e3f5aa6f 100644
--- a/components/autofill/content/renderer/autofill_agent.h
+++ b/components/autofill/content/renderer/autofill_agent.h
@@ -149,7 +149,7 @@ class AutofillAgent : public content::RenderFrameObserver,
// content::RenderFrameObserver:
void DidCommitProvisionalLoad(bool is_new_navigation,
- bool is_same_page_navigation) override;
+ bool is_same_document_navigation) override;
void DidFinishDocumentLoad() override;
void WillSendSubmitEvent(const blink::WebFormElement& form) override;
void WillSubmitForm(const blink::WebFormElement& form) override;
@@ -189,8 +189,8 @@ class AutofillAgent : public content::RenderFrameObserver,
void firstUserGestureObserved() override;
void ajaxSucceeded() override;
- // Called when a same-page navigation is detected.
- void OnSamePageNavigationCompleted();
+ // Called when a same-document navigation is detected.
+ void OnSameDocumentNavigationCompleted();
// Helper method which collects unowned elements (i.e., those not inside a
// form tag) and writes them into |output|. Returns true if the process is
// successful, and all conditions for firing events are true.
« no previous file with comments | « chrome/renderer/safe_browsing/phishing_classifier_delegate.cc ('k') | components/autofill/content/renderer/autofill_agent.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698